@@ -19,7 +19,7 @@ map_cmd <- function(command, alternative = FALSE) {
       ggplot2::ggplot()
     ',
     bathy_pb = '
-      ggspatial::layer_spatial(data = X$shapefiles$bathy, aes(fill = depth), show.legend = bathy.legend, color = bathy.border.col, size = bathy.size) +
+      ggspatial::layer_spatial(data = X$shapefiles$bathy, aes(fill = depth), show.legend = bathy.legend, color = bathy.border.col, size = bathy.size, alpha = bathy.alpha) +
       scale_fill_manual(name = "Depth (m)", values = colorRampPalette(c("#F7FBFF", "#DEEBF7", "#9ECAE1", "#4292C6", "#08306B"))(nlevels(X$shapefiles$bathy@data$depth)), guide =
         if(bathy.legend) {
           guide_legend(order = 1, override.aes = list(colour = NA))
@@ -28,7 +28,7 @@ map_cmd <- function(command, alternative = FALSE) {
         })
     ',
     bathy_pg = '
-      ggspatial::layer_spatial(data = X$shapefiles$bathy, aes(fill = depth), show.legend = bathy.legend, color = bathy.border.col, size = bathy.size) +
+      ggspatial::layer_spatial(data = X$shapefiles$bathy, aes(fill = depth), show.legend = bathy.legend, color = bathy.border.col, size = bathy.size, alpha = bathy.alpha) +
       scale_fill_grey("Depth (m)", start = 1, end = 0.5, guide =
         if(bathy.legend) {
           guide_legend(order = 1, override.aes = list(colour = NA))
@@ -54,11 +54,11 @@ map_cmd <- function(command, alternative = FALSE) {
       scale_x_continuous(breaks = X$map.grid$lon.breaks, expand = c(0,0.1)) +
       labs(y = "Latitude (decimal degrees)", x = "Longitude (decimal degrees)") + {
         if(packageVersion("ggplot2") > "3.3.3")
-        coord_sf(xlim = X$map.limits[1:2], ylim = X$map.limits[3:4],
+        coord_sf(xlim = X$map.limits[1:2], ylim = X$map.limits[3:4], 
                  default_crs = NULL, crs = sf::st_crs(X$proj), default = TRUE)
       } + {
         if(packageVersion("ggplot2") <= "3.3.3") 
-        coord_sf(xlim = X$map.limits[1:2], ylim = X$map.limits[3:4],
+        coord_sf(xlim = X$map.limits[1:2], ylim = X$map.limits[3:4], 
                  crs = sf::st_crs(X$proj), default = TRUE)
       } +
       theme_map(base_size = base_size, grid.col = grid.col, grid.size = grid.size) +
